@@ -1,6 +1,6 @@
 package Workflow::State;
 
-# $Id: State.pm,v 1.11 2006/12/14 08:18:15 jonasbn Exp $
+# $Id: State.pm,v 1.13 2007/01/29 13:46:08 alech Exp $
 
 use strict;
 use base qw( Workflow::Base );
@@ -9,7 +9,7 @@ use Workflow::Condition::Evaluate;
 use Workflow::Exception qw( workflow_error );
 use Workflow::Factory   qw( FACTORY );
 
-$Workflow::State::VERSION  = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
+$Workflow::State::VERSION  = sprintf("%d.%02d", q$Revision: 1.13 $ =~ /(\d+)\.(\d+)/);
 
 my @FIELDS = qw( state description );
 __PACKAGE__->mk_accessors( @FIELDS );
@@ -53,6 +53,15 @@ sub is_action_available {
     return ( ! $@ );
 }
 
+sub clear_condition_cache {
+    my ($self) = @_;
+    foreach my $condition (keys %{ $self->{'_condition_result_cache'} }) {
+        delete $self->{'_condition_result_cache'}->{$condition};
+        $log->is_debug &&
+            $log->debug( "Deleted cached condition result for $condition" );
+    } 
+}
+
 sub evaluate_action {
     my ( $self, $wf, $action_name ) = @_;
     $log ||= get_logger();
@@ -62,6 +71,8 @@ sub evaluate_action {
     # NOTE: this will throw an exception if C<$action_name> is not
     # contained in this state, so there's no need to do it explicitly
 
+    $self->clear_condition_cache();
+
     my @conditions = $self->get_conditions( $action_name );
     foreach my $condition ( @conditions ) {
         my $condition_name;
@@ -194,7 +205,7 @@ sub get_autorun_action_name {
     my $pre_error = "State '$state' should be automatically executed but ";
     if ( scalar @actions > 1 ) {
         workflow_error "$pre_error there are multiple actions available ",
-                       "for execution. Actions are: ", join( @actions, ', ' );
+                       "for execution. Actions are: ", join( ', ', @actions );
     }
     if ( scalar @actions == 0 ) {
         workflow_error "$pre_error there are no actions available for execution.";
